#!/bin/bash

# Reproducible timestamp according to:
# https://reproducible-builds.org/docs/source-date-epoch/
SOURCE_DATE_EPOCH=$(git log -1 --pretty=%ct)

set -eu

pkgname=iceweasel
brandingver=120.0
brandingrel=1

srcdir=src
distdir=${pkgname}-${brandingver}
tarball=${pkgname}_${brandingver}-${brandingrel}.branding.tar.xz

rm -rf $distdir/
mkdir -pv $distdir

cp -rv $srcdir/* $distdir/

rm -f ${tarball}{,.sig}

# Reproducible archive metadata according to:
# https://reproducible-builds.org/docs/archives/#full-example
tar --sort=name \
    --mtime="@${SOURCE_DATE_EPOCH}" \
    --owner=0 --group=0 --numeric-owner \
    --pax-option=exthdr.name=%d/PaxHeaders/%f,delete=atime,delete=ctime \
    -cJf $tarball $distdir

gpg --output ${tarball}.sig --detach-sig $tarball
rm -rf $distdir

echo "dist tarball:   $tarball"
echo "dist signature: $tarball.sig"
